==> ecs-1.122.0-sources.jar: software/amazon/awscdk/services/ecs/FargatePlatformVersion.java <==
package software.amazon.awscdk.services.ecs;

/**
 * The platform version on which to run your service.
 * <p>
 * @see https://docs.aws.amazon.com/AmazonECS/latest/developerguide/platform_versions.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.34.0 (build 9b72778)", date = "2021-09-08T20:44:44.498Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ecs.$Module.class, fqn = "@aws-cdk/aws-ecs.FargatePlatformVersion")
public enum FargatePlatformVersion {
    /**
     * The latest, recommended platform version.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    LATEST,
    /**
     * Version 1.4.0.
     * <p>
     * Supports EFS endpoints, CAP_SYS_PTRACE Linux capability,
     * network performance metrics in CloudWatch Container Insights,
     * consolidated 20 GB ephemeral volume.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    VERSION1_4,
    /**
     * Version 1.3.0.
     * <p>
     * Supports secrets, task recycling.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    VERSION1_3,
    /**
     * Version 1.2.0.
     * <p>
     * Supports private registries.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    VERSION1_2,
    /**
     * Version 1.1.0.
     * <p>
     * Supports task metadata, health checks, service discovery.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    VERSION1_1,
    /**
     * Initial release.
     * <p>
     * Based on Amazon Linux 2017.09.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    VERSION1_0,
}

==> ecs-1.173.0-sources.jar: software/amazon/awscdk/services/ecs/FargatePlatformVersion.java <==
package software.amazon.awscdk.services.ecs;

/**
 * The platform version on which to run your service.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * Cluster cluster;
 * ScheduledFargateTask scheduledFargateTask = ScheduledFargateTask.Builder.create(this, "ScheduledFargateTask")
 *         .cluster(cluster)
 *         .scheduledFargateTaskImageOptions(ScheduledFargateTaskImageOptions.builder()
 *                 .image(ContainerImage.fromRegistry("amazon/amazon-ecs-sample"))
 *                 .memoryLimitMiB(512)
 *                 .build())
 *         .schedule(Schedule.expression("rate(1 minute)"))
 *         .platformVersion(FargatePlatformVersion.LATEST)
 *         .build();
 * </pre></blockquote>
 * <p>
 * @see <a href="https://docs.aws.amazon.com/AmazonECS/latest/developerguide/platform_versions.html">https://docs.aws.amazon.com/AmazonECS/latest/developerguide/platform_versions.html</a>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.67.0 (build 2c027f5)", date = "2022-09-16T18:50:35.814Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ecs.$Module.class, fqn = "@aws-cdk/aws-ecs.FargatePlatformVersion")
public enum FargatePlatformVersion {
    /**
     * The latest, recommended platform version.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    LATEST,
    /**
     * Version 1.4.0.
     * <p>
     * Supports EFS endpoints, CAP_SYS_PTRACE Linux capability,
     * network performance metrics in CloudWatch Container Insights,
     * consolidated 20 GB ephemeral volume.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    VERSION1_4,
    /**
     * Version 1.3.0.
     * <p>
     * Supports secrets, task recycling.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    VERSION1_3,
    /**
     * Version 1.2.0.
     * <p>
     * Supports private registries.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    VERSION1_2,
    /**
     * Version 1.1.0.
     * <p>
     * Supports task metadata, health checks, service discovery.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    VERSION1_1,
    /**
     * Initial release.
     * <p>
     * Based on Amazon Linux 2017.09.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    VERSION1_0,
}
